# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

import enum

import winrt.system
from winrt._winrt_windows_management_workplace import (
    MdmPolicy,
    WorkplaceSettings,
)

__all__ = [
    "MessagingSyncPolicy",
    "MdmPolicy",
    "WorkplaceSettings",
]

class MessagingSyncPolicy(enum.IntEnum):
    DISALLOWED = 0
    ALLOWED = 1
    REQUIRED = 2

